@@ -12,7 +12,6 @@
 
 #include <QAbstractListModel>
 #include <QQmlEngine>
-#include <QtQml>
 
 static QObject *event_plugins_manager_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
@@ -32,3 +31,5 @@ void CalendarPlugin::registerTypes(const char *uri)
     qmlRegisterSingletonType<EventPluginsManager>(uri, 2, 0, "EventPluginsManager", event_plugins_manager_provider);
     qmlRegisterUncreatableType<EventDataDecorator>(uri, 2, 0, "EventDataDecorator", QStringLiteral("Unable to create EventDataDecorator from QML"));
 }
+
+#include "moc_calendarplugin.cpp"
